@@ -1,3 +1,3 @@
-from month_periods import MonthsPeriodEnum
+from .month_periods import MonthsPeriodEnum
 from .geometry_types import GeometryTypeEnum
 from .http_methods import HttpMethodEnum
